[Rivet-svn] r2648 - in trunk: data/anainfo data/plotinfo src/Analyses

blackhole at projects.hepforge.org blackhole at projects.hepforge.org
Mon Aug 9 16:28:26 BST 2010


Author: fsiegert
Date: Mon Aug  9 16:28:26 2010
New Revision: 2648

Log:
Add MC analysis for higgs[-> tau tau] + jets production.

Added:
   trunk/data/anainfo/MC_HJETS.info
      - copied, changed from r2647, trunk/data/anainfo/MC_ZJETS.info
   trunk/data/plotinfo/MC_HJETS.plot
      - copied, changed from r2647, trunk/data/plotinfo/MC_ZJETS.plot
   trunk/src/Analyses/MC_HJETS.cc
      - copied, changed from r2647, trunk/src/Analyses/MC_ZJETS.cc
Modified:
   trunk/data/anainfo/Makefile.am
   trunk/data/plotinfo/Makefile.am
   trunk/src/Analyses/Makefile.am

Copied and modified: trunk/data/anainfo/MC_HJETS.info (from r2647, trunk/data/anainfo/MC_ZJETS.info)
==============================================================================
--- trunk/data/anainfo/MC_ZJETS.info	Thu Aug  5 17:40:47 2010	(r2647, copy source)
+++ trunk/data/anainfo/MC_HJETS.info	Mon Aug  9 16:28:26 2010	(r2648)
@@ -1,16 +1,15 @@
-Name: MC_ZJETS
-Summary: Monte Carlo validation observables for $Z[e^+ \, e^-]$ + jets production
+Name: MC_HJETS
+Summary: Monte Carlo validation observables for $h[\tau^+ \, \tau^-]$ + jets production
 Status: VALIDATED
 Authors:
  - Frank Siegert <frank.siegert at durham.ac.uk>
 References:
 RunInfo:
-  $e^+ e^-$ + jets analysis. Needs mass cut on lepton pair to avoid 
-  photon singularity, e.g. a min range of $66 < m_{ee} < 116$ GeV
+  $h [\to \tau^+ \tau^-]$ + jets.
 NumEvents: 1000000
 PtCuts: [0]
 Description:
-  Available observables are Z mass, pT of jets 1-4, jet multiplicity,
-  $\Delta\eta(Z, \text{jet1})$, $\Delta R(\text{jet2}, \text{jet3})$, 
+  Available observables are Higgs mass, pT of jets 1-4, jet multiplicity,
+  $\Delta\eta(h, \text{jet1})$, $\Delta R(\text{jet2}, \text{jet3})$, 
   differential jet rates 0->1, 1->2, 2->3, 3->4, integrated 0--4 jet 
   rates.

Modified: trunk/data/anainfo/Makefile.am
==============================================================================
--- trunk/data/anainfo/Makefile.am	Thu Aug  5 17:40:47 2010	(r2647)
+++ trunk/data/anainfo/Makefile.am	Mon Aug  9 16:28:26 2010	(r2648)
@@ -77,6 +77,7 @@
   MC_TTBAR.info \
   MC_JETS.info \
   MC_PHOTONJETS.info \
+  MC_HJETS.info \
   MC_WJETS.info \
   MC_ZJETS.info \
   OPAL_1998_S3780481.info \

Copied and modified: trunk/data/plotinfo/MC_HJETS.plot (from r2647, trunk/data/plotinfo/MC_ZJETS.plot)
==============================================================================
--- trunk/data/plotinfo/MC_ZJETS.plot	Thu Aug  5 17:40:47 2010	(r2647, copy source)
+++ trunk/data/plotinfo/MC_HJETS.plot	Mon Aug  9 16:28:26 2010	(r2648)
@@ -1,64 +1,64 @@
-# BEGIN PLOT /MC_ZJETS/Z_jet1_dR
+# BEGIN PLOT /MC_HJETS/H_jet1_dR
 Title=
-XLabel=$\Delta R(\text{Z, 1st jet})$
-YLabel=$\text{d}\sigma/\text{d}\Delta R(\text{Z, 1st jet})$
+XLabel=$\Delta R(\text{h, 1st jet})$
+YLabel=$\text{d}\sigma/\text{d}\Delta R(\text{h, 1st jet})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/Z_jet1_deta
+# BEGIN PLOT /MC_HJETS/H_jet1_deta
 Title=
-XLabel=$\Delta{\eta}(\text{Z, 1st jet})$
-YLabel=$\text{d}\sigma/\text{d}\Delta{\eta}(\text{Z, 1st jet})$
+XLabel=$\Delta{\eta}(\text{h, 1st jet})$
+YLabel=$\text{d}\sigma/\text{d}\Delta{\eta}(\text{h, 1st jet})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/Z_mass
-Title=Z mass
-XLabel=$m_{\text{Z}}$ [GeV]
-YLabel=$\text{d}\sigma/\text{d}m_{\text{Z}}$
+# BEGIN PLOT /MC_HJETS/H_mass
+Title=Higgs mass
+XLabel=$m_{\text{h}}$ [GeV]
+YLabel=$\text{d}\sigma/\text{d}m_{\text{h}}$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/Z_pT
-Title=Z $p_\perp$
-XLabel=$p_\perp^{\text{Z}}$ [GeV]
-YLabel=$\text{d}\sigma/\text{d}p_\perp^{\text{Z}}$
+# BEGIN PLOT /MC_HJETS/H_pT
+Title=Higgs $p_\perp$
+XLabel=$p_\perp^{\text{h}}$ [GeV]
+YLabel=$\text{d}\sigma/\text{d}p_\perp^{\text{h}}$
 LogX=1
 LegendXPos=0.5
 LegendYPos=0.5
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/Z_pT_peak
-Title=Z $p_\perp$ in peak region
-XLabel=$p_\perp^{\text{Z}}$ [GeV]
-YLabel=$\text{d}\sigma/\text{d}p_\perp^{\text{Z}}$
+# BEGIN PLOT /MC_HJETS/H_pT_peak
+Title=Higgs $p_\perp$ in peak region
+XLabel=$p_\perp^{\text{h}}$ [GeV]
+YLabel=$\text{d}\sigma/\text{d}p_\perp^{\text{h}}$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/Z_y
-Title=Z rapidity
-XLabel=$y_{\text{Z}}$
-YLabel=$\text{d}\sigma/\text{d}y_{\text{Z}}$
+# BEGIN PLOT /MC_HJETS/H_y
+Title=Higgs rapidity
+XLabel=$y_{\text{h}}$
+YLabel=$\text{d}\sigma/\text{d}y_{\text{h}}$
 LegendXPos=0.8
 LegendYPos=0.5
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/Z_phi
-Title=Z azimuthal angle
-XLabel=$\phi_{\text{Z}}$
-YLabel=$\text{d}\sigma/\text{d}\phi_{\text{Z}}$
+# BEGIN PLOT /MC_HJETS/H_phi
+Title=Higgs azimuthal angle
+XLabel=$\phi_{\text{h}}$
+YLabel=$\text{d}\sigma/\text{d}\phi_{\text{h}}$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/lepton_pT
+# BEGIN PLOT /MC_HJETS/lepton_pT
 Title=Lepton $p_\perp$
 XLabel=$p_\perp^{\text{l}}$ [GeV]
 YLabel=$\text{d}\sigma/\text{d}p_\perp^{\text{l}}$
 LogX=1
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/lepton_eta
+# BEGIN PLOT /MC_HJETS/lepton_eta
 Title=Lepton $\eta$
 XLabel=$\eta_{\text{l}}$ [GeV]
 YLabel=$\text{d}\sigma/\text{d}\eta_{\text{l}}$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jets_dR_12
+# BEGIN PLOT /MC_HJETS/jets_dR_12
 Title=Separation between leading and second leading jet
 XLabel=$\Delta{R}(\text{jet 1, jet 2})$
 YLabel=$\text{d}\sigma/\text{d}\Delta{R}(\text{jet 1, jet 2})$
@@ -66,145 +66,145 @@
 LegendYPos=0.5
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jets_dR_13
+# BEGIN PLOT /MC_HJETS/jets_dR_13
 Title=
 XLabel=$\Delta{R}(\text{jet 1, jet 3})$
 YLabel=$\text{d}\sigma/\text{d}\Delta{R}(\text{jet 1, jet 3})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jets_dR_14
+# BEGIN PLOT /MC_HJETS/jets_dR_14
 Title=
 XLabel=$\Delta{R}(\text{jet 1, jet 4})$
 YLabel=$\text{d}\sigma/\text{d}\Delta{R}(\text{jet 1, jet 4})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jets_dR_23
+# BEGIN PLOT /MC_HJETS/jets_dR_23
 Title=
 XLabel=$\Delta{R}(\text{jet 2, jet 3})$
 YLabel=$\text{d}\sigma/\text{d}\Delta{R}(\text{jet 2, jet 3})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jets_dR_24
+# BEGIN PLOT /MC_HJETS/jets_dR_24
 Title=
 XLabel=$\Delta{R}(\text{jet 2, jet 4})$
 YLabel=$\text{d}\sigma/\text{d}\Delta{R}(\text{jet 2, jet 4})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jets_dR_34
+# BEGIN PLOT /MC_HJETS/jets_dR_34
 Title=
 XLabel=$\Delta{R}(\text{jet 3, jet 4})$
 YLabel=$\text{d}\sigma/\text{d}\Delta{R}(\text{jet 3, jet 4})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jets_deta_12
+# BEGIN PLOT /MC_HJETS/jets_deta_12
 Title=
 XLabel=$\Delta\eta(\text{jet 1, jet 2})$
 YLabel=$\text{d}\sigma/\text{d}\Delta\eta(\text{jet 1, jet 2})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jets_deta_13
+# BEGIN PLOT /MC_HJETS/jets_deta_13
 Title=
 XLabel=$\Delta\eta(\text{jet 1, jet 3})$
 YLabel=$\text{d}\sigma/\text{d}\Delta\eta(\text{jet 1, jet 3})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jets_deta_14
+# BEGIN PLOT /MC_HJETS/jets_deta_14
 Title=
 XLabel=$\Delta\eta(\text{jet 1, jet 4})$
 YLabel=$\text{d}\sigma/\text{d}\Delta\eta(\text{jet 1, jet 4})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jets_deta_23
+# BEGIN PLOT /MC_HJETS/jets_deta_23
 Title=
 XLabel=$\Delta\eta(\text{jet 2, jet 3})$
 YLabel=$\text{d}\sigma/\text{d}\Delta\eta(\text{jet 2, jet 3})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jets_deta_24
+# BEGIN PLOT /MC_HJETS/jets_deta_24
 Title=
 XLabel=$\Delta\eta(\text{jet 2, jet 4})$
 YLabel=$\text{d}\sigma/\text{d}\Delta\eta(\text{jet 2, jet 4})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jets_deta_34
+# BEGIN PLOT /MC_HJETS/jets_deta_34
 Title=
 XLabel=$\Delta\eta(\text{jet 3, jet 4})$
 YLabel=$\text{d}\sigma/\text{d}\Delta\eta(\text{jet 3, jet 4})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_eta_1
+# BEGIN PLOT /MC_HJETS/jet_eta_1
 Title=
 XLabel=$\eta(\text{jet 1})$
 YLabel=$\text{d}\sigma/\text{d}\eta(\text{jet 1})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_eta_2
+# BEGIN PLOT /MC_HJETS/jet_eta_2
 Title=
 XLabel=$\eta(\text{jet 2})$
 YLabel=$\text{d}\sigma/\text{d}\eta(\text{jet 2})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_eta_3
+# BEGIN PLOT /MC_HJETS/jet_eta_3
 Title=
 XLabel=$\eta(\text{jet 3})$
 YLabel=$\text{d}\sigma/\text{d}\eta(\text{jet 3})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_eta_4
+# BEGIN PLOT /MC_HJETS/jet_eta_4
 Title=
 XLabel=$\eta(\text{jet 4})$
 YLabel=$\text{d}\sigma/\text{d}\eta(\text{jet 4})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_y_1
+# BEGIN PLOT /MC_HJETS/jet_y_1
 Title=
 XLabel=$y(\text{jet 1})$
 YLabel=$\text{d}\sigma/\text{d}y(\text{jet 1})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_y_2
+# BEGIN PLOT /MC_HJETS/jet_y_2
 Title=
 XLabel=$y(\text{jet 2})$
 YLabel=$\text{d}\sigma/\text{d}y(\text{jet 2})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_y_3
+# BEGIN PLOT /MC_HJETS/jet_y_3
 Title=
 XLabel=$y(\text{jet 3})$
 YLabel=$\text{d}\sigma/\text{d}y(\text{jet 3})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_y_4
+# BEGIN PLOT /MC_HJETS/jet_y_4
 Title=
 XLabel=$y(\text{jet 4})$
 YLabel=$\text{d}\sigma/\text{d}y(\text{jet 4})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_mass_1
+# BEGIN PLOT /MC_HJETS/jet_mass_1
 Title=
 XLabel=$m(\text{jet 1})$
 YLabel=$\text{d}\sigma/\text{d}m(\text{jet 1})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_mass_2
+# BEGIN PLOT /MC_HJETS/jet_mass_2
 Title=
 XLabel=$m(\text{jet 2})$
 YLabel=$\text{d}\sigma/\text{d}m(\text{jet 2})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_mass_3
+# BEGIN PLOT /MC_HJETS/jet_mass_3
 Title=
 XLabel=$m(\text{jet 3})$
 YLabel=$\text{d}\sigma/\text{d}m(\text{jet 3})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_mass_4
+# BEGIN PLOT /MC_HJETS/jet_mass_4
 Title=
 XLabel=$m(\text{jet 4})$
 YLabel=$\text{d}\sigma/\text{d}m(\text{jet 4})$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_multi_exclusive
+# BEGIN PLOT /MC_HJETS/jet_multi_exclusive
 Title=Exclusive jet multiplicity
 XLabel=$N_{\text{jet}}$
 YLabel=$\sigma(N_{\text{jet}})$
@@ -213,7 +213,7 @@
 ErrorBands=1
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_multi_inclusive
+# BEGIN PLOT /MC_HJETS/jet_multi_inclusive
 Title=Inclusive jet multiplicity
 XLabel=$N_{\text{jet}}$
 YLabel=$\sigma(\geq N_{\text{jet}})$
@@ -222,7 +222,7 @@
 ErrorBands=1
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_multi_ratio
+# BEGIN PLOT /MC_HJETS/jet_multi_ratio
 Title=Ratio of jet multiplicity
 XLabel=$N_{\text{jet}}$
 YLabel=$\sigma(\geq N_{\text{jet}})/\sigma(\geq N_{\text{jet}}-1)$
@@ -232,7 +232,7 @@
 ErrorBands=1
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/log10_R_0
+# BEGIN PLOT /MC_HJETS/log10_R_0
 Title=$\log_{10}$(Integrated $0$ jet rate in $k_\perp$ [GeV])
 XLabel=$\log_{10}(d_{\text{cut}}/\text{GeV})$
 YLabel=$R_{0}$
@@ -240,31 +240,31 @@
 LegendXPos=1.2
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/log10_R_1
+# BEGIN PLOT /MC_HJETS/log10_R_1
 Title=$\log_{10}$(Integrated $1$ jet rate in $k_\perp$ [GeV])
 XLabel=$\log_{10}(d_{\text{cut}}/\text{GeV})$
 YLabel=$R_{1}$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/log10_R_2
+# BEGIN PLOT /MC_HJETS/log10_R_2
 Title=$\log_{10}$(Integrated $2$ jet rate in $k_\perp$ [GeV])
 XLabel=$\log_{10}(d_{\text{cut}}/\text{GeV})$
 YLabel=$R_{2}$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/log10_R_3
+# BEGIN PLOT /MC_HJETS/log10_R_3
 Title=$\log_{10}$(Integrated $3$ jet rate in $k_\perp$ [GeV])
 XLabel=$\log_{10}(d_{\text{cut}}/\text{GeV})$
 YLabel=$R_{3}$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/log10_R_4
+# BEGIN PLOT /MC_HJETS/log10_R_4
 Title=$\log_{10}$(Integrated $4$ jet rate in $k_\perp$ [GeV])
 XLabel=$\log_{10}(d_{\text{cut}}/\text{GeV})$
 YLabel=$R_{\geq4}$
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/log10_d_01
+# BEGIN PLOT /MC_HJETS/log10_d_01
 Title=$\log_{10}$($k_\perp$ jet resolution $0 \to 1$ [GeV])
 XLabel=$\log_{10}(d_{01}/\text{GeV})$
 YLabel=$\text{d}\sigma/\text{d}\log_{10}(d_{01})$
@@ -272,7 +272,7 @@
 LegendYPos=0.5
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/log10_d_12
+# BEGIN PLOT /MC_HJETS/log10_d_12
 Title=$\log_{10}$($k_\perp$ jet resolution $1 \to 2$ [GeV])
 XLabel=$\log_{10}(d_{12}/\text{GeV})$
 YLabel=$\text{d}\sigma/\text{d}\log_{10}(d_{12})$
@@ -280,7 +280,7 @@
 LegendYPos=0.5
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/log10_d_23
+# BEGIN PLOT /MC_HJETS/log10_d_23
 Title=$\log_{10}$($k_\perp$ jet resolution $2 \to 3$ [GeV])
 XLabel=$\log_{10}(d_{23}/\text{GeV})$
 YLabel=$\text{d}\sigma/\text{d}\log_{10}(d_{23})$
@@ -288,7 +288,7 @@
 LegendYPos=0.5
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/log10_d_34
+# BEGIN PLOT /MC_HJETS/log10_d_34
 Title=$\log_{10}$($k_\perp$ jet resolution $3 \to 4$ [GeV])
 XLabel=$\log_{10}(d_{34}/\text{GeV})$
 YLabel=$\text{d}\sigma/\text{d}\log_{10}(d_{34})$
@@ -296,28 +296,28 @@
 LegendYPos=0.5
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_pT_1
+# BEGIN PLOT /MC_HJETS/jet_pT_1
 Title=
 XLabel=$p_\perp(\text{jet 1})$
 YLabel=$\text{d}\sigma/\text{d}p_\perp(\text{jet 1})$
 LogX=1
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_pT_2
+# BEGIN PLOT /MC_HJETS/jet_pT_2
 Title=
 XLabel=$p_\perp(\text{jet 2})$
 YLabel=$\text{d}\sigma/\text{d}p_\perp(\text{jet 2})$
 LogX=1
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_pT_3
+# BEGIN PLOT /MC_HJETS/jet_pT_3
 Title=
 XLabel=$p_\perp(\text{jet 3})$
 YLabel=$\text{d}\sigma/\text{d}p_\perp(\text{jet 3})$
 LogX=1
 # END PLOT
 
-# BEGIN PLOT /MC_ZJETS/jet_pT_4
+# BEGIN PLOT /MC_HJETS/jet_pT_4
 Title=
 XLabel=$p_\perp(\text{jet 4})$
 YLabel=$\text{d}\sigma/\text{d}p_\perp(\text{jet 4})$

Modified: trunk/data/plotinfo/Makefile.am
==============================================================================
--- trunk/data/plotinfo/Makefile.am	Thu Aug  5 17:40:47 2010	(r2647)
+++ trunk/data/plotinfo/Makefile.am	Mon Aug  9 16:28:26 2010	(r2648)
@@ -75,6 +75,7 @@
   MC_TTBAR.plot \
   MC_JETS.plot \
   MC_PHOTONJETS.plot \
+  MC_HJETS.plot \
   MC_WJETS.plot \
   MC_ZJETS.plot \
   OPAL_1998_S3780481.plot \

Copied and modified: trunk/src/Analyses/MC_HJETS.cc (from r2647, trunk/src/Analyses/MC_ZJETS.cc)
==============================================================================
--- trunk/src/Analyses/Makefile.am	Thu Aug  5 17:40:47 2010	(r2647)
+++ trunk/src/Analyses/Makefile.am	Mon Aug  9 16:28:26 2010	(r2648)
@@ -145,6 +145,7 @@
     ExampleAnalysis.cc \
     MC_JETS.cc \
     MC_PHOTONJETS.cc \
+    MC_HJETS.cc \
     MC_WJETS.cc \
     MC_ZJETS.cc \
     MC_LEADINGJETS.cc \


More information about the Rivet-svn mailing list
--- trunk/src/Analyses/MC_ZJETS.cc	Thu Aug  5 17:40:47 2010	(r2647, copy source)
+++ trunk/src/Analyses/MC_HJETS.cc	Mon Aug  9 16:28:26 2010	(r2648)
@@ -8,13 +8,13 @@
 namespace Rivet {
 
 
-  /// @brief MC validation analysis for Z + jets events
-  class MC_ZJETS : public MC_JetAnalysis {
+  /// @brief MC validation analysis for higgs [-> tau tau] + jets events
+  class MC_HJETS : public MC_JetAnalysis {
   public:
 
     /// Default constructor
-    MC_ZJETS()
-      : MC_JetAnalysis("MC_ZJETS", 4, "Jets")
+    MC_HJETS()
+      : MC_JetAnalysis("MC_HJETS", 4, "Jets")
     {
       setNeedsCrossSection(true);
     }
@@ -25,18 +25,18 @@
 
     /// Book histograms
     void init() {
-      ZFinder zfinder(-3.5, 3.5, 25.0*GeV, ELECTRON, 65.0*GeV, 115.0*GeV, 0.2);
-      addProjection(zfinder, "ZFinder");
-      FastJets jetpro(zfinder.remainingFinalState(), FastJets::KT, 0.7);
+      ZFinder hfinder(-3.5, 3.5, 25.0*GeV, TAU, 115.0*GeV, 125.0*GeV, 0.2);
+      addProjection(hfinder, "Hfinder");
+      FastJets jetpro(hfinder.remainingFinalState(), FastJets::KT, 0.7);
       addProjection(jetpro, "Jets");
 
-      _h_Z_mass = bookHistogram1D("Z_mass", 50, 66.0, 116.0);
-      _h_Z_pT = bookHistogram1D("Z_pT", logBinEdges(100, 1.0, 0.5*sqrtS()));
-      _h_Z_pT_peak = bookHistogram1D("Z_pT_peak", 25, 0.0, 25.0);
-      _h_Z_y = bookHistogram1D("Z_y", 40, -4.0, 4.0);
-      _h_Z_phi = bookHistogram1D("Z_phi", 25, 0.0, TWOPI);
-      _h_Z_jet1_deta = bookHistogram1D("Z_jet1_deta", 50, -5.0, 5.0);
-      _h_Z_jet1_dR = bookHistogram1D("Z_jet1_dR", 25, 0.5, 7.0);
+      _h_H_mass = bookHistogram1D("H_mass", 50, 119.7, 120.3);
+      _h_H_pT = bookHistogram1D("H_pT", logBinEdges(100, 1.0, 0.5*sqrtS()));
+      _h_H_pT_peak = bookHistogram1D("H_pT_peak", 25, 0.0, 25.0);
+      _h_H_y = bookHistogram1D("H_y", 40, -4.0, 4.0);
+      _h_H_phi = bookHistogram1D("H_phi", 25, 0.0, TWOPI);
+      _h_H_jet1_deta = bookHistogram1D("H_jet1_deta", 50, -5.0, 5.0);
+      _h_H_jet1_dR = bookHistogram1D("H_jet1_dR", 25, 0.5, 7.0);
       _h_lepton_pT = bookHistogram1D("lepton_pT", logBinEdges(100, 10.0, 0.25*sqrtS()));
       _h_lepton_eta = bookHistogram1D("lepton_eta", 40, -4.0, 4.0);
 
@@ -47,19 +47,19 @@
 
     /// Do the analysis
     void analyze(const Event & e) {
-      const ZFinder& zfinder = applyProjection<ZFinder>(e, "ZFinder");
-      if (zfinder.particles().size()!=1) {
+      const ZFinder& hfinder = applyProjection<ZFinder>(e, "Hfinder");
+      if (hfinder.particles().size()!=1) {
         vetoEvent;
       }
       const double weight = e.weight();
 
-      FourMomentum zmom(zfinder.particles()[0].momentum());
-      _h_Z_mass->fill(zmom.mass(),weight);
-      _h_Z_pT->fill(zmom.pT(),weight);
-      _h_Z_pT_peak->fill(zmom.pT(),weight);
-      _h_Z_y->fill(zmom.rapidity(),weight);
-      _h_Z_phi->fill(zmom.azimuthalAngle(),weight);
-      foreach (const Particle& l, zfinder.constituentsFinalState().particles()) {
+      FourMomentum hmom(hfinder.particles()[0].momentum());
+      _h_H_mass->fill(hmom.mass(),weight);
+      _h_H_pT->fill(hmom.pT(),weight);
+      _h_H_pT_peak->fill(hmom.pT(),weight);
+      _h_H_y->fill(hmom.rapidity(),weight);
+      _h_H_phi->fill(hmom.azimuthalAngle(),weight);
+      foreach (const Particle& l, hfinder.constituentsFinalState().particles()) {
         _h_lepton_pT->fill(l.momentum().pT(), weight);
         _h_lepton_eta->fill(l.momentum().eta(), weight);
       }
@@ -67,8 +67,8 @@
       const FastJets& jetpro = applyProjection<FastJets>(e, "Jets");
       const Jets& jets = jetpro.jetsByPt(20.0*GeV);
       if (jets.size() > 0) {
-        _h_Z_jet1_deta->fill(zmom.eta()-jets[0].momentum().eta(), weight);
-        _h_Z_jet1_dR->fill(deltaR(zmom, jets[0].momentum()), weight);
+        _h_H_jet1_deta->fill(hmom.eta()-jets[0].momentum().eta(), weight);
+        _h_H_jet1_dR->fill(deltaR(hmom, jets[0].momentum()), weight);
       }
 
       MC_JetAnalysis::analyze(e);
@@ -77,13 +77,13 @@
 
     /// Finalize
     void finalize() {
-      scale(_h_Z_mass, crossSection()/sumOfWeights());
-      scale(_h_Z_pT, crossSection()/sumOfWeights());
-      scale(_h_Z_pT_peak, crossSection()/sumOfWeights());
-      scale(_h_Z_y, crossSection()/sumOfWeights());
-      scale(_h_Z_phi, crossSection()/sumOfWeights());
-      scale(_h_Z_jet1_deta, crossSection()/sumOfWeights());
-      scale(_h_Z_jet1_dR, crossSection()/sumOfWeights());
+      scale(_h_H_mass, crossSection()/sumOfWeights());
+      scale(_h_H_pT, crossSection()/sumOfWeights());
+      scale(_h_H_pT_peak, crossSection()/sumOfWeights());
+      scale(_h_H_y, crossSection()/sumOfWeights());
+      scale(_h_H_phi, crossSection()/sumOfWeights());
+      scale(_h_H_jet1_deta, crossSection()/sumOfWeights());
+      scale(_h_H_jet1_dR, crossSection()/sumOfWeights());
       scale(_h_lepton_pT, crossSection()/sumOfWeights());
       scale(_h_lepton_eta, crossSection()/sumOfWeights());
 
@@ -97,13 +97,13 @@
 
     /// @name Histograms
     //@{
-    AIDA::IHistogram1D * _h_Z_mass;
-    AIDA::IHistogram1D * _h_Z_pT;
-    AIDA::IHistogram1D * _h_Z_pT_peak;
-    AIDA::IHistogram1D * _h_Z_y;
-    AIDA::IHistogram1D * _h_Z_phi;
-    AIDA::IHistogram1D * _h_Z_jet1_deta;
-    AIDA::IHistogram1D * _h_Z_jet1_dR;
+    AIDA::IHistogram1D * _h_H_mass;
+    AIDA::IHistogram1D * _h_H_pT;
+    AIDA::IHistogram1D * _h_H_pT_peak;
+    AIDA::IHistogram1D * _h_H_y;
+    AIDA::IHistogram1D * _h_H_phi;
+    AIDA::IHistogram1D * _h_H_jet1_deta;
+    AIDA::IHistogram1D * _h_H_jet1_dR;
     AIDA::IHistogram1D * _h_lepton_pT;
     AIDA::IHistogram1D * _h_lepton_eta;
     //@}
@@ -113,6 +113,6 @@
 
 
   // This global object acts as a hook for the plugin system
-  AnalysisBuilder<MC_ZJETS> plugin_MC_ZJETS;
+  AnalysisBuilder<MC_HJETS> plugin_MC_HJETS;
 
 }

Modified: trunk/src/Analyses/Makefile.am
==============================================================================